@@ -1,8 +1,8 @@
 """This module implements "Local" classes that mimic their associated `cloudpathlib` non-local
 counterparts but use the local filesystem in place of cloud storage. They can be used as drop-in
 replacements, with the intent that you can use them as mock or monkepatch substitutes in your
-tests. See ["Testing code that uses cloudpathlib"
-](https://cloudpathlib.drivendata.org/testing_mocked_cloudpathlib/) for usage examples.
+tests. See ["Testing code that uses cloudpathlib"](../../testing_mocked_cloudpathlib/) for usage
+examples.
 """
 
 from .implementations import (
